==> openshift-model-console-5.10.1-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConsolePluginSpecFluentImpl<A extends io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent<A>{
  public ConsolePluginSpecFluentImpl() {
  }
  public ConsolePluginSpecFluentImpl(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpec instance) {
    this.withDisplayName(instance.getDisplayName()); 
    this.withService(instance.getService()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String displayName;
  private io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginServiceBuilder service;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDisplayName() {
    return this.displayName;
  }
  public A withDisplayName(java.lang.String displayName) {
    this.displayName=displayName; return (A) this;
  }
  public java.lang.Boolean hasDisplayName() {
    return this.displayName != null;
  }
  
  /**
   * Method is deprecated. use withDisplayName instead.
   */
  @java.lang.Deprecated
  public A withNewDisplayName(java.lang.String arg0) {
    return (A)withDisplayName(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildService instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginService getService() {
    return this.service!=null?this.service.build():null;
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginService buildService() {
    return this.service!=null?this.service.build():null;
  }
  public A withService(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginService service) {
    _visitables.get("service").remove(this.service);
    if (service!=null){ this.service= new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginServiceBuilder(service); _visitables.get("service").add(this.service);} return (A) this;
  }
  public java.lang.Boolean hasService() {
    return this.service != null;
  }
  public A withNewService(java.lang.String basePath,java.lang.String name,java.lang.String namespace,java.lang.Integer port) {
    return (A)withService(new ConsolePluginService(basePath, name, namespace, port));
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ServiceNested<A> withNewService() {
    return new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluentImpl.ServiceNestedImpl();
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ServiceNested<A> withNewServiceLike(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginService item) {
    return new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluentImpl.ServiceNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ServiceNested<A> editService() {
    return withNewServiceLike(getService());
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ServiceNested<A> editOrNewService() {
    return withNewServiceLike(getService() != null ? getService(): new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginServiceBuilder().build());
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ServiceNested<A> editOrNewServiceLike(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginService item) {
    return withNewServiceLike(getService() != null ? getService(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsolePluginSpecFluentImpl that = (ConsolePluginSpecFluentImpl) o;
    if (displayName != null ? !displayName.equals(that.displayName) :that.displayName != null) return false;
    if (service != null ? !service.equals(that.service) :that.service != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(displayName,  service,  additionalProperties,  super.hashCode());
  }
  public class ServiceNestedImpl<N> extends io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginServiceFluentImpl<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ServiceNested<N>> implements io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ServiceNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ServiceNestedImpl(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginService item) {
      this.builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginServiceBuilder(this, item);
    }
    ServiceNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginServiceBuilder(this);
    }
    io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginServiceBuilder builder;
    public N and() {
      return (N) ConsolePluginSpecFluentImpl.this.withService(builder.build());
    }
    public N endService() {
      return and();
    }
    
  }
  
}

==> openshift-model-console-5.11.1-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConsolePluginSpecFluentImpl<A extends io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent<A>{
  public ConsolePluginSpecFluentImpl() {
  }
  public ConsolePluginSpecFluentImpl(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpec instance) {
    this.withDisplayName(instance.getDisplayName()); 
    this.withProxy(instance.getProxy()); 
    this.withService(instance.getService()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String displayName;
  private io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyBuilder proxy;
  private io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginServiceBuilder service;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDisplayName() {
    return this.displayName;
  }
  public A withDisplayName(java.lang.String displayName) {
    this.displayName=displayName; return (A) this;
  }
  public java.lang.Boolean hasDisplayName() {
    return this.displayName != null;
  }
  
  /**
   * Method is deprecated. use withDisplayName instead.
   */
  @java.lang.Deprecated
  public A withNewDisplayName(java.lang.String arg0) {
    return (A)withDisplayName(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildProxy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxy getProxy() {
    return this.proxy!=null?this.proxy.build():null;
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxy buildProxy() {
    return this.proxy!=null?this.proxy.build():null;
  }
  public A withProxy(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxy proxy) {
    _visitables.get("proxy").remove(this.proxy);
    if (proxy!=null){ this.proxy= new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyBuilder(proxy); _visitables.get("proxy").add(this.proxy);} return (A) this;
  }
  public java.lang.Boolean hasProxy() {
    return this.proxy != null;
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ProxyNested<A> withNewProxy() {
    return new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluentImpl.ProxyNestedImpl();
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ProxyNested<A> withNewProxyLike(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxy item) {
    return new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluentImpl.ProxyNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ProxyNested<A> editProxy() {
    return withNewProxyLike(getProxy());
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ProxyNested<A> editOrNewProxy() {
    return withNewProxyLike(getProxy() != null ? getProxy(): new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyBuilder().build());
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ProxyNested<A> editOrNewProxyLike(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxy item) {
    return withNewProxyLike(getProxy() != null ? getProxy(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildService instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginService getService() {
    return this.service!=null?this.service.build():null;
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginService buildService() {
    return this.service!=null?this.service.build():null;
  }
  public A withService(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginService service) {
    _visitables.get("service").remove(this.service);
    if (service!=null){ this.service= new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginServiceBuilder(service); _visitables.get("service").add(this.service);} return (A) this;
  }
  public java.lang.Boolean hasService() {
    return this.service != null;
  }
  public A withNewService(java.lang.String basePath,java.lang.String name,java.lang.String namespace,java.lang.Integer port) {
    return (A)withService(new ConsolePluginService(basePath, name, namespace, port));
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ServiceNested<A> withNewService() {
    return new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluentImpl.ServiceNestedImpl();
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ServiceNested<A> withNewServiceLike(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginService item) {
    return new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluentImpl.ServiceNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ServiceNested<A> editService() {
    return withNewServiceLike(getService());
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ServiceNested<A> editOrNewService() {
    return withNewServiceLike(getService() != null ? getService(): new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginServiceBuilder().build());
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ServiceNested<A> editOrNewServiceLike(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginService item) {
    return withNewServiceLike(getService() != null ? getService(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsolePluginSpecFluentImpl that = (ConsolePluginSpecFluentImpl) o;
    if (displayName != null ? !displayName.equals(that.displayName) :that.displayName != null) return false;
    if (proxy != null ? !proxy.equals(that.proxy) :that.proxy != null) return false;
    if (service != null ? !service.equals(that.service) :that.service != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(displayName,  proxy,  service,  additionalProperties,  super.hashCode());
  }
  public class ProxyNestedImpl<N> extends io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluentImpl<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ProxyNested<N>> implements io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ProxyNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ProxyNestedImpl(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxy item) {
      this.builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyBuilder(this, item);
    }
    ProxyNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyBuilder(this);
    }
    io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyBuilder builder;
    public N and() {
      return (N) ConsolePluginSpecFluentImpl.this.withProxy(builder.build());
    }
    public N endProxy() {
      return and();
    }
    
  }
  public class ServiceNestedImpl<N> extends io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginServiceFluentImpl<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ServiceNested<N>> implements io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginSpecFluent.ServiceNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ServiceNestedImpl(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginService item) {
      this.builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginServiceBuilder(this, item);
    }
    ServiceNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginServiceBuilder(this);
    }
    io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginServiceBuilder builder;
    public N and() {
      return (N) ConsolePluginSpecFluentImpl.this.withService(builder.build());
    }
    public N endService() {
      return and();
    }
    
  }
  
}
